@@ -2,7 +2,15 @@ from jupyterlite_core.manager import LiteManager
 
 
 class BaseBuildPack(LiteManager):
-    def __init__(self, repository, configuration_file, ide, output_dir):
+    def __init__(
+        self,
+        repository,
+        configuration_file,
+        ide,
+        output_dir,
+        forgiving=False,
+        ignore=[],
+    ):
         super().__init__()
         self.initialize()
 
@@ -10,6 +18,7 @@ class BaseBuildPack(LiteManager):
         self.repository = repository
         self.configuration_file = configuration_file
         self.ide = ide
+        self.forgiving = forgiving
 
         # JupyterLite
         if self.ide == "jupyterlab":
@@ -17,3 +26,6 @@ class BaseBuildPack(LiteManager):
 
         self.contents = (self.repository,)
         self.output_dir = output_dir
+
+        # Append .pixi to be ignore
+        self.ignore_contents = (*self.ignore_contents, "/\\.pixi")
